@@ -1,8 +1,10 @@
 
-use std::{any::{Any, TypeId}, marker::PhantomData, sync::{Arc, RwLock}};
+use std::{any::{Any, TypeId}, marker::PhantomData, sync::Arc};
 
 use crate::{container::Container, injection::Injection, injector::Injector};
 
+use tokio::sync::RwLock;
+
 pub struct TypeBuilder<TType> where TType: Injection + 'static {
     pub phantom: PhantomData<TType>,
     pub constructor: Option<Box<dyn Fn(&mut Injector) -> Result<Box<dyn Any>,crate::DiError>>>,
